==> enlightenment-0.16.999.023.tar.gz: enlightenment-0.16.999.023/src/bin/e_includes.h <==
/*
 * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
 */
#include "e_mmx.h"
#include "e_object.h"
#include "e_user.h"
#include "e_manager.h"
#include "e_path.h"
#include "e_ipc.h"
#include "e_error.h"
#include "e_container.h"
#include "e_zone.h"
#include "e_desk.h"
#include "e_border.h"
#include "e_pointer.h"
#include "e_config.h"
#include "e_menu.h"
#include "e_icon.h"
#include "e_box.h"
#include "e_entry.h"
#include "e_init.h"
#include "e_int_menus.h"
#include "e_module.h"
#include "e_apps.h"
#include "e_atoms.h"
#include "e_utils.h"
#include "e_canvas.h"
#include "e_focus.h"
#include "e_place.h"
#include "e_resist.h"
#include "e_startup.h"
#include "e_hints.h"
#include "e_gadman.h"
#include "e_gadget.h"
#include "e_signals.h"
#include "e_xinerama.h"
#include "e_table.h"
#include "e_layout.h"
#include "e_font.h"
#include "e_intl.h"
#include "e_theme.h"
#include "e_dnd.h"
#include "e_bindings.h"
#include "e_moveresize.h"
#include "e_actions.h"
#include "e_popup.h"
#include "e_ipc_codec.h"
#include "e_test.h"
#include "e_prefix.h"
#include "e_datastore.h"
#include "e_msg.h"
#include "e_winlist.h"
#include "e_alert.h"
#include "e_maximize.h"
#include "e_grabinput.h"
#include "e_bg.h"
#include "e_remember.h"
#include "e_win.h"
#include "e_pan.h"
#include "e_dialog.h"
#include "e_configure.h"
#include "e_about.h"
#include "e_theme_about.h"
#include "e_apps_cache.h"
#include "e_fileman.h"
#include "e_fileman_smart.h"
#include "e_fileman_file.h"
#include "e_fileman_icon.h"
#include "e_widget.h"
#include "e_widget_check.h"
#include "e_widget_radio.h"
#include "e_widget_framelist.h"
#include "e_widget_list.h"
#include "e_widget_button.h"
#include "e_widget_label.h"
#include "e_widget_frametable.h"
#include "e_widget_table.h"
#include "e_widget_entry.h"
#include "e_widget_image.h"
#include "e_widget_iconsel.h"
#include "e_config_dialog.h"
#include "e_int_config_focus.h"
#include "e_icon_grid.h"
#include "e_icon_canvas.h"
#include "e_int_config_desks.h"
#include "e_int_border_locks.h"
#include "e_thumb.h"
#include "e_int_border_remember.h"
#include "e_eap_editor.h"
#include "e_scrollframe.h"
#include "e_file_selector.h"
#include "e_file_dialog.h"
#include "e_widget_fileman.h"
#include "e_int_border_menu.h"
#include "e_ilist.h"
#include "e_livethumb.h"
#include "e_int_border_border.h"
#include "e_widget_ilist.h"
#include "e_slider.h"
#include "e_widget_slider.h"
#include "e_int_config_window_manipulation.h"
#include "e_int_config_window_display.h"
#include "e_int_config_background.h"
#include "e_int_config_theme.h"
#include "e_int_config_menus.h"
#include "e_int_config_general.h"
#include "e_int_config_performance.h"
#include "e_int_config_winlist.h"
#include "e_deskpreview.h"
#include "e_exebuf.h"
#include "e_int_config_modules.h"
#include "e_exehist.h"
#include "e_color_class.h"

==> enlightenment-0.16.999.027.tar.gz: enlightenment-0.16.999.027/src/bin/e_includes.h <==
/*
 * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
 */
#include "e_mmx.h"
#include "e_object.h"
#include "e_user.h"
#include "e_manager.h"
#include "e_path.h"
#include "e_ipc.h"
#include "e_error.h"
#include "e_container.h"
#include "e_zone.h"
#include "e_desk.h"
#include "e_border.h"
#include "e_pointer.h"
#include "e_config.h"
#include "e_menu.h"
#include "e_icon.h"
#include "e_box.h"
#include "e_entry.h"
#include "e_init.h"
#include "e_int_menus.h"
#include "e_module.h"
#include "e_apps.h"
#include "e_atoms.h"
#include "e_utils.h"
#include "e_canvas.h"
#include "e_focus.h"
#include "e_place.h"
#include "e_resist.h"
#include "e_startup.h"
#include "e_hints.h"
#include "e_gadman.h"
#include "e_gadget.h"
#include "e_signals.h"
#include "e_xinerama.h"
#include "e_table.h"
#include "e_layout.h"
#include "e_font.h"
#include "e_intl.h"
#include "e_theme.h"
#include "e_dnd.h"
#include "e_bindings.h"
#include "e_moveresize.h"
#include "e_actions.h"
#include "e_popup.h"
#include "e_ipc_codec.h"
#include "e_test.h"
#include "e_prefix.h"
#include "e_datastore.h"
#include "e_msg.h"
#include "e_winlist.h"
#include "e_alert.h"
#include "e_maximize.h"
#include "e_grabinput.h"
#include "e_bg.h"
#include "e_remember.h"
#include "e_win.h"
#include "e_pan.h"
#include "e_dialog.h"
#include "e_configure.h"
#include "e_about.h"
#include "e_theme_about.h"
#include "e_apps_cache.h"
#include "e_fileman.h"
#include "e_fileman_smart.h"
#include "e_fileman_file.h"
#include "e_fileman_icon.h"
#include "e_fileman_mime.h"
#include "e_widget.h"
#include "e_widget_check.h"
#include "e_widget_radio.h"
#include "e_widget_framelist.h"
#include "e_widget_list.h"
#include "e_widget_button.h"
#include "e_widget_label.h"
#include "e_widget_frametable.h"
#include "e_widget_table.h"
#include "e_widget_entry.h"
#include "e_widget_image.h"
#include "e_widget_iconsel.h"
#include "e_config_dialog.h"
#include "e_int_config_focus.h"
#include "e_icon_grid.h"
#include "e_icon_canvas.h"
#include "e_int_config_desks.h"
#include "e_int_border_locks.h"
#include "e_thumb.h"
#include "e_int_border_remember.h"
#include "e_eap_editor.h"
#include "e_scrollframe.h"
#include "e_file_selector.h"
#include "e_file_dialog.h"
#include "e_widget_fileman.h"
#include "e_int_border_menu.h"
#include "e_ilist.h"
#include "e_livethumb.h"
#include "e_int_border_border.h"
#include "e_widget_ilist.h"
#include "e_widget_config_list.h"
#include "e_slider.h"
#include "e_widget_slider.h"
#include "e_int_config_window_manipulation.h"
#include "e_int_config_window_display.h"
#include "e_int_config_background.h"
#include "e_int_config_background_import.h"
#include "e_int_config_theme.h"
#include "e_int_config_menus.h"
#include "e_int_config_keybindings.h"
#include "e_int_config_cursor.h"
#include "e_int_config_fonts.h"
#include "e_int_config_startup.h"
#include "e_int_config_performance.h"
#include "e_int_config_winlist.h"
#include "e_int_config_display.h"
#include "e_int_config_desklock.h"
#include "e_int_config_exebuf.h"
#include "e_int_config_cfgdialogs.h"
#include "e_int_config_hinting.h"
#include "e_deskpreview.h"
#include "e_exebuf.h"
#include "e_desklock.h"
#include "e_int_config_modules.h"
#include "e_exehist.h"
#include "e_color_class.h"
#include "e_widget_textblock.h"
#include "e_apps_error.h"
#include "e_stolen.h"
#include "e_gadcon.h"
#include "e_shelf.h"
#include "e_tlist.h"
#include "e_widget_tlist.h"
#include "e_widget_preview.h"
#include "e_int_config_paths.h"
#include "e_int_shelf_config.h"
#include "e_int_config_shelf.h"
#include "e_int_gadcon_config.h"
